﻿local FRename3 = {}

function FRename3.ID()
  return "A88BA05B-F468-4E00-8FD0-614F4C7750E5"
end

function FRename3.Installed()
  return Plugin.Exist(FRename3.ID())
end

-- Start the plugin directly from the active panel, as if using F11
function FRename3.ExecutePanel()
  return Plugin.Call(FRename3.ID(), "panel")
end

-- Start the plugin using a filelist. Only filenames without paths are
-- supported.
function FRename3.ExecuteFiles(directory, filelist)
  return Plugin.Call(FRename3.ID(), "files", directory, filelist);
end

-- Check whether the current editor is FRename's editor
function FRename3.IsEditor()
  return Plugin.SyncCall(FRename3.ID(), "is_editor");
end

-- Check whether the current editor is FRename's editor
-- and the cursor is located on a rename-item line.
function FRename3.IsEditorLine()
  return Plugin.SyncCall(FRename3.ID(), "is_editor_line");
end

-- In editor, move the cursor to the destination filename
function FRename3.CursorToFileName()
  return Plugin.Call(FRename3.ID(), "cursor_to_filename");
end

-- In editor, move the cursor to the destination filename's extension
function FRename3.CursorToExtension()
  return Plugin.Call(FRename3.ID(), "cursor_to_extension");
end

-- In editor, switch the cursor between the destination filename and the beginning of the line
function FRename3.SmartHome()
  return Plugin.Call(FRename3.ID(), "smart_home");
end

-- In editor, switch the cursor between the destination filename's extension and the end of the line
function FRename3.SmartEnd()
  return Plugin.Call(FRename3.ID(), "smart_end");
end

-- In editor, select the destination filename
function FRename3.SelectFileNames()
  return Plugin.Call(FRename3.ID(), "select_filenames");
end

-- In editor, delete filename from the cursor position to the file's extension
function FRename3.DeleteTillExtension()
  return Plugin.Call(FRename3.ID(), "delete_till_extension");
end



-- Usage demonstrations

function FRename3.DemoExecutePanel()
  return FRename3.ExecutePanel();
end

function FRename3.DemoExecuteFiles()
  files = {"a.txt", "b.txt"};
  files = table.concat(files, "\n"); -- required by LuaMacro, not FRename3
  return FRename3.ExecuteFiles("c:\\somedir", files);
end

function FRename3.DemoIsEditor()
  if FRename3.IsEditor() then
    far.Message("This is a FRename3 editor","", 0);
  else
    far.Message("This is not a FRename3 editor","", 0);
  end
end

function FRename3.DemoIsEditorLine()
  if FRename3.IsEditorLine() then
    far.Message("This is a FRename3 editor line","", 0);
  else
    far.Message("This is not a FRename3 editor line","", 0);
  end
end

function FRename3.DemoCursorToFileName()
  FRename3.CursorToFileName();
end

function FRename3.DemoSelectFileNames()
  FRename3.SelectFileNames();
end

-- Macro

Macro
{
  description = "FRename3";
  area = "Shell Editor";
  key = "CtrlAltShiftF7";
  action = function()
    return FRename3.DemoExecutePanel();
  end;
}

Macro
{
  description = "FRename3 - select destination filenames";
  area = "Editor";
  key = "CtrlC";
  flags = "NoEVSelection";
  condition = function(key, data)
    return FRename3.Installed() and FRename3.IsEditor();
  end;
  action = function()
    return FRename3.SelectFileNames();
  end;
}

Macro
{
  description = "FRename3 - delete filename till extension";
  area = "Editor";
  key = "CtrlD";
  flags = "NoEVSelection";
  condition = function(key, data)
    return FRename3.Installed() and FRename3.IsEditorLine();
  end;
  action = function()
    return FRename3.DeleteTillExtension();
  end;
}

Macro
{
  description = "FRename3 - delete filename till extension";
  area = "Editor";
  key = "CtrlK";
  condition = function(key, data)
    return FRename3.Installed() and FRename3.IsEditorLine();
  end;
  action = function()
    return FRename3.DeleteTillExtension();
  end;
}

Macro
{
  description = "FRename3 - smart HOME (switch the cursor between the destination filename and the beginning of the line)";
  area = "Editor";
  key = "Home";
  condition = function(key, data)
    return FRename3.Installed() and FRename3.IsEditorLine();
  end;
  action = function()
    return FRename3.SmartHome();
  end;
}

Macro
{
  description = "FRename3 - smart END (switch the cursor between the destination filename's extension and the end of the line)";
  area = "Editor";
  key = "End";
  condition = function(key, data)
    return FRename3.Installed() and FRename3.IsEditorLine();
  end;
  action = function()
    return FRename3.SmartEnd();
  end;
}
